@@ -9,10 +9,11 @@ The main entry point for the mitosheet package, this command
 line interface allows you to set some toggles in the user.json
 """
 import sys
+from mitosheet.experiments.experiment_utils import set_experiment
 
 from mitosheet.user.db import set_user_field
 from mitosheet.user import initialize_user
-from mitosheet.user.schemas import UJ_MITOSHEET_PRO, UJ_MITOSHEET_TELEMETRY, UJ_USER_EMAIL
+from mitosheet.user.schemas import UJ_MITOSHEET_PRO, UJ_MITOSHEET_TELEMETRY, UJ_RECEIVED_CHECKLISTS, UJ_RECEIVED_TOURS, UJ_USER_EMAIL
 from mitosheet.startup.startup_utils import create_startup_file, remove_startup_file
 from mitosheet.user.utils import check_pro_acccess_code
 
@@ -59,6 +60,13 @@ def main() -> None:
             print("Clearing email")
             set_user_field(UJ_USER_EMAIL, '')
             print("Email cleared")
+        if sys.argv[-1] == 'cleartours':
+            print("Clearing tours")
+            set_user_field(UJ_RECEIVED_TOURS, [])
+        if sys.argv[-1] == 'clearchecklists':
+            print("Clearing checklists")
+            set_user_field(UJ_RECEIVED_CHECKLISTS, {})
+            print("Checklists cleared")
         if sys.argv[-1] == 'turnoffdataframebutton':
             print("Turning off the 'View in Mito' dataframe button")
             remove_startup_file()
@@ -67,7 +75,11 @@ def main() -> None:
             print("Turning on the 'View in Mito' dataframe button")
             create_startup_file()
             print("Turned on the 'View in Mito' dataframe button\nThe next time you launch Jupyter Lab, the button will be visible")
-
-
+        if len(sys.argv) > 2:
+            if sys.argv[-3] == 'setexperiment':
+                print("Setting experiment", sys.argv[-2], "to variant", sys.argv[-1])
+                set_experiment(sys.argv[-2], sys.argv[-1])
+                print("Experiment set")
+        
 if __name__ == '__main__':
     main()
\ No newline at end of file
