@@ -10,6 +10,7 @@ from mitosheet.code_chunks.empty_code_chunk import EmptyCodeChunk
 
 from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
+from mitosheet.step_performers.utils import get_param
 from mitosheet.types import GraphID
 
 
@@ -27,20 +28,8 @@ class GraphDeleteStepPerformer(StepPerformer):
         return 'graph_delete'
 
     @classmethod
-    def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
-        graph_id = params['graph_id']
-        old_graph_tab_name = prev_state.graph_data_dict[graph_id]
-        params['old_graph_tab_name'] = old_graph_tab_name
-        return params
-
-    @classmethod
-    def execute( # type: ignore
-        cls,
-        prev_state: State,
-        graph_id: GraphID,
-        old_graph_tab_name: str,
-        **params
-    ) -> Tuple[State, Optional[Dict[str, Any]]]:
+    def execute(cls, prev_state: State, params: Dict[str, Any]) -> Tuple[State, Optional[Dict[str, Any]]]:
+        graph_id: GraphID = get_param(params, 'graph_id')
 
         # Create a new step and save the parameters
         post_state = prev_state.copy()
@@ -75,9 +64,5 @@ class GraphDeleteStepPerformer(StepPerformer):
         ]
     
     @classmethod
-    def get_modified_dataframe_indexes( # type: ignore
-        cls, 
-        graph_id: GraphID,
-        **params
-    ) -> Set[int]:
+    def get_modified_dataframe_indexes(cls, params: Dict[str, Any]) -> Set[int]:
         return {-1}
