@@ -10,6 +10,8 @@ from mitosheet.state import (
     DATAFRAME_SOURCE_MERGED,
     DATAFRAME_SOURCE_PASSED,
     DATAFRAME_SOURCE_PIVOTED,
+    DATAFRAME_SOURCE_TRANSPOSED,
+    DATAFRAME_SOURCE_MELTED,
     FORMAT_ACCOUNTING,
     FORMAT_CURRENCY,
     FORMAT_DEFAULT,
@@ -60,6 +62,10 @@ def get_enum_from_ts_file(path, enum_name):
         # Remove trailing commas
         if enum_item_code_line.endswith(","):
             enum_item_code_line = enum_item_code_line[:-1]
+        
+        # If it's a comment, ignore it
+        if enum_item_code_line.startswith('//'):
+            continue
 
         # Split into keys and values
         [name, value] = enum_item_code_line.split(" = ")
@@ -148,7 +154,7 @@ def test_step_types_match():
     )
 
 
-def test_df_sources_matche():
+def test_df_sources_match():
     df_sources = get_enum_from_ts_file("./src/types.tsx", "DFSource")
     assert set(df_sources.values()) == set(
         [
@@ -157,12 +163,14 @@ def test_df_sources_matche():
             DATAFRAME_SOURCE_PIVOTED,
             DATAFRAME_SOURCE_MERGED,
             DATAFRAME_SOURCE_DUPLICATED,
+            DATAFRAME_SOURCE_TRANSPOSED,
+            DATAFRAME_SOURCE_MELTED
         ]
     )
 
 
 def test_user_json_fields_match():
-    user_json_fields = get_enum_from_ts_file("./src/api.tsx", "UserJsonFields")
+    user_json_fields = get_enum_from_ts_file("./src/jupyter/api.tsx", "UserJsonFields")
     assert set(user_json_fields.values()) == set(USER_JSON_DEFAULT.keys())
 
 
