@@ -1,23 +1,31 @@
+#!/usr/bin/env python
+# coding: utf-8
+
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
+
 """
 Utilities for creating and initializing the user.json
 file with the current schema
 """
 
+import json
+import os
 from datetime import datetime
 from typing import List, Optional
-from mitosheet.user.utils import is_local_deployment
-from mitosheet.utils import get_random_id
-import os
-import json
 
 from mitosheet._version import __version__
-from mitosheet.user.schemas import (
-    UJ_STATIC_USER_ID, UJ_USER_EMAIL, UJ_MITOSHEET_CURRENT_VERSION, 
-    UJ_MITOSHEET_LAST_UPGRADED_DATE, UJ_MITOSHEET_LAST_FIFTY_USAGES
-)
-from mitosheet.user.schemas import GITHUB_ACTION_EMAIL, GITHUB_ACTION_ID, USER_JSON_DEFAULT
+from mitosheet.user.db import (MITO_FOLDER, USER_JSON_PATH, get_user_field,
+                               set_user_field)
+from mitosheet.user.schemas import (GITHUB_ACTION_EMAIL, GITHUB_ACTION_ID,
+                                    UJ_MITOSHEET_CURRENT_VERSION,
+                                    UJ_MITOSHEET_LAST_FIFTY_USAGES,
+                                    UJ_MITOSHEET_LAST_UPGRADED_DATE,
+                                    UJ_STATIC_USER_ID, UJ_USER_EMAIL,
+                                    USER_JSON_DEFAULT)
 from mitosheet.user.upgrade import try_upgrade_user_json_to_current_version
-from mitosheet.user.db import MITO_FOLDER, USER_JSON_PATH, get_user_json_object, set_user_field, get_user_field
+from mitosheet.user.utils import is_local_deployment
+
 
 def is_user_json_exists_and_valid_json() -> bool:
     """
@@ -80,7 +88,7 @@ def initialize_user(call_identify: bool=True) -> None:
     # get upgraded on our infrastructure anyways
     mitosheet_current_version = get_user_field(UJ_MITOSHEET_CURRENT_VERSION)
     if mitosheet_current_version != __version__ and is_local_deployment():
-        from mitosheet.mito_analytics import log
+        from mitosheet.telemetry.telemetry_utils import log
         set_user_field(UJ_MITOSHEET_CURRENT_VERSION, __version__)
         set_user_field(UJ_MITOSHEET_LAST_UPGRADED_DATE, datetime.today().strftime('%Y-%m-%d'))
         # Log the upgrade. Note that this runs when the user _actually_ changes
@@ -107,5 +115,5 @@ def initialize_user(call_identify: bool=True) -> None:
     # Reidentify the user, just in case things have changed
     # but only if we were told to identify
     if call_identify:
-        from mitosheet.mito_analytics import identify
+        from mitosheet.telemetry.telemetry_utils import identify
         identify()
